@@ -33,7 +33,7 @@ using namespace sigc;
 JACKWrapper::JACKWrapper(const std::string& client_name) 
   : m_client(0) {
 
-  if (m_client = jack_client_open(client_name.c_str(), JackNullOption, 0)) {
+  if ((m_client = jack_client_open(client_name.c_str(), JackNullOption, 0))) {
     sem_init(&m_portreg_sem, 0, 0);
     signal_timeout().connect(mem_fun(*this, &JACKWrapper::check_portreg), 100);
     jack_set_port_registration_callback(m_client, 
@@ -85,6 +85,7 @@ void JACKWrapper::port_registration_callback(jack_port_id_t, int, void* arg) {
 
 int JACKWrapper::graph_order_callback(void* arg) {
   sem_post(&static_cast<JACKWrapper*>(arg)->m_portreg_sem);
+  return 0;
 }
 
 
@@ -198,10 +199,10 @@ bool JACKWrapper::check_portreg() {
         }
       }
     }
-      
-      
 
   }
+  
+  return true;
 }
 
 
