@@ -32,7 +32,7 @@
 class LASHWrapper : public sigc::trackable {
 public:
   
-  LASHWrapper(int* argv, char*** argv);
+  LASHWrapper(int* argc, char*** argv);
 
   void start_lashd();
   void stop_lashd();
