@@ -413,7 +413,7 @@ void PopupMenu::disconnect(const std::string& output, const std::string& input)
 
 void PopupMenu::dump_recent() {
   ofstream ofs((Glib::getenv("HOME") + "/.glashctl_recent").c_str());
-  int i = m_recent_sessions.size() - 10;
+  size_t i = m_recent_sessions.size() - 10;
   i = (i < 0 ? 0 : i);
   for ( ; i < m_recent_sessions.size(); ++i)
     ofs<<m_recent_sessions[i].first<<endl<<m_recent_sessions[i].second<<endl;
